@@ -32,8 +32,8 @@ class YOLO(ml_model.MLModel):
 
     def _get_objects_from_s3(self, dest_dir):
         s3_client = self._get_s3_client()
-        file_to_download = '{mod_name}_latest.{ext}'.format(
-                mod_name=self.model_name, ext='h5')
+        file_to_download = '{mod_name}_{mod_id}.{ext}'.format(
+                mod_name=self.model_name, mod_id=self.model_id, ext='h5')
         s3_client.download_file(
             os.environ['S3_MODEL_BUCKET'],
             file_to_download, dest_dir+file_to_download)
